==> org.hl7.fhir.utilities-4.2.0-sources.jar: org/hl7/fhir/utilities/validation/ValidationOptions.java <==
package org.hl7.fhir.utilities.validation;


public class ValidationOptions {
  public enum ValueSetMode {
    ALL_CHECKS, CHECK_MEMERSHIP_ONLY, NO_MEMBERSHIP_CHECK
  }

  private String language;
  private boolean useServer = true;
  private boolean useClient = true;
  private boolean guessSystem = false;
  private ValueSetMode valueSetMode = ValueSetMode.ALL_CHECKS;

  public ValidationOptions() {
    super();
  }

  public ValidationOptions(String language) {
    super();
    this.language = language;
  }

  public String getLanguage() {
    return language;
  }

  
  public boolean isUseServer() {
    return useServer;
  }

  public boolean isUseClient() {
    return useClient;
  }

  public boolean isGuessSystem() {
    return guessSystem;
  }
  
  private ValidationOptions copy() {
    ValidationOptions n = new ValidationOptions(language);
    n.useServer = useServer;
    n.useClient = useClient;
    n.guessSystem = guessSystem;    
    return n;
  }
  
  public ValidationOptions setLanguage(String language) {
    ValidationOptions n = this.copy();
    n.language = language;
    return n;
  }


  public ValidationOptions noServer() {
    ValidationOptions n = this.copy();
    n.useServer = false;
    return n;
  }
  
  public ValidationOptions noClient() {
    ValidationOptions n = this.copy();
    n.useClient = false;
    return n;
  }

  public ValidationOptions guessSystem() {
    ValidationOptions n = this.copy();
    n.guessSystem = false;
    return n;
  }
  

  public String toJson() {
    return "\"lang\":\""+language+"\", \"useServer\":\""+Boolean.toString(useServer)+"\", \"useClient\":\""+Boolean.toString(useClient)+"\", \"guessSystem\":\""+Boolean.toString(guessSystem)+"\", \"valueSetMode\":\""+valueSetMode.toString()+"\"";
  }

  public static ValidationOptions defaults() {
    return new ValidationOptions("en-US");
  }

  public ValidationOptions checkValueSetOnly() {
    ValidationOptions n = this.copy();
    n.valueSetMode = ValueSetMode.CHECK_MEMERSHIP_ONLY;
    return n;
  }

  public ValidationOptions noCheckValueSetMembership() {
    ValidationOptions n = this.copy();
    n.valueSetMode = ValueSetMode.NO_MEMBERSHIP_CHECK;
    return n;
  }

  public ValueSetMode getValueSetMode() {
    return valueSetMode;
  }

  
}

==> org.hl7.fhir.utilities-5.6.92-sources.jar: org/hl7/fhir/utilities/validation/ValidationOptions.java <==
package org.hl7.fhir.utilities.validation;


public class ValidationOptions {
  public enum ValueSetMode {
    ALL_CHECKS, CHECK_MEMERSHIP_ONLY, NO_MEMBERSHIP_CHECK
  }

  private String language;
  private boolean useServer = true;
  private boolean useClient = true;
  private boolean guessSystem = false;
  private ValueSetMode valueSetMode = ValueSetMode.ALL_CHECKS;
  private boolean vsAsUrl;
  private boolean versionFlexible = true;

  public ValidationOptions() {
    super();
  }

  public ValidationOptions(String language) {
    super();
    this.language = language;
  }

  public String getLanguage() {
    return language;
  }

  
  public boolean isUseServer() {
    return useServer;
  }

  public boolean isUseClient() {
    return useClient;
  }

  public boolean isGuessSystem() {
    return guessSystem;
  }
  
  public ValidationOptions copy() {
    ValidationOptions n = new ValidationOptions(language);
    n.useServer = useServer;
    n.useClient = useClient;
    n.guessSystem = guessSystem; 
    n.vsAsUrl = vsAsUrl;
    n.versionFlexible = versionFlexible;
    return n;
  }
  
  public ValidationOptions setLanguage(String language) {
    ValidationOptions n = this.copy();
    n.language = language;
    return n;
  }


  public ValidationOptions noServer() {
    ValidationOptions n = this.copy();
    n.useServer = false;
    return n;
  }
  
  public ValidationOptions noClient() {
    ValidationOptions n = this.copy();
    n.useClient = false;
    return n;
  }

  public ValidationOptions guessSystem() {
    ValidationOptions n = this.copy();
    n.guessSystem = true;
    return n;
  }
  

  public String toJson() {
    return "\"lang\":\""+language+"\", \"useServer\":\""+Boolean.toString(useServer)+"\", \"useClient\":\""+Boolean.toString(useClient)+"\", "+
       "\"guessSystem\":\""+Boolean.toString(guessSystem)+"\", \"valueSetMode\":\""+valueSetMode.toString()+"\", \"versionFlexible\":\""+Boolean.toString(versionFlexible)+"\"";
  }

  public static ValidationOptions defaults() {
    return new ValidationOptions("en-US");
  }

  public ValidationOptions checkValueSetOnly() {
    ValidationOptions n = this.copy();
    n.valueSetMode = ValueSetMode.CHECK_MEMERSHIP_ONLY;
    return n;
  }

  public ValidationOptions noCheckValueSetMembership() {
    ValidationOptions n = this.copy();
    n.valueSetMode = ValueSetMode.NO_MEMBERSHIP_CHECK;
    return n;
  }

  public ValueSetMode getValueSetMode() {
    return valueSetMode;
  }

  public ValidationOptions setVsAsUrl() {
    vsAsUrl = true;
    return this;
  }

  public boolean getVsAsUrl() {
    return vsAsUrl;
  }

  public boolean versionFlexible() {
    return versionFlexible;
  }

  public ValidationOptions setVersionFlexible(boolean value) {
    ValidationOptions n = this.copy();
    n.versionFlexible = value;
    return n;
  }

  
}
